# Pactus Python SDK

This SDK is used to provide python utilities to interact with the [Pactus](https://pactus.org) blockchain, create transactions, sign messages or generate keys.

You can build apps on the top of Pactus using this SDK with ease in python.

## Install

You can install this packages using `pip`:

```bash
pip install pactus-sdk
```

## Development

After making any changes, make sure all tests are passing by running:

```bash
python pactus/test.py
```

Also, make sure you run [linter](https://docs.astral.sh/ruff/) after your change and formatter by running:

```bash
ruff format # formatting code style
ruff check # running linter
```

## Contribution

Contributions are welcome! Feel free to add features, fix bugs, or improve documentation via pull requests.

## License

This packages is published under [MIT License](./LICENSE).
